@@ -1,33 +1,36 @@
 import json
 from io import BytesIO
 from zipfile import ZipFile
-from http.client import HTTPConnection, HTTPException
+from http.client import HTTPException
 import requests
 from .zip import unzip_content, unzip_csv_content
-from urllib.parse import urlparse
 
 
-def native_get(url, headers={}, encoding='utf-8'):
-    url_parts = urlparse(url)
-    conn = HTTPConnection(url_parts.hostname, port=url_parts.port if url_parts.port is not None else 80)
-    try:
-        conn.request('GET', url, headers=headers)
-        response = conn.getresponse()
-        if response.status == 200:
-            byte_array_content = response.read()
-            return byte_array_content if encoding is None else byte_array_content.decode(encoding)
-        elif response.status == 301:
-            byte_array_content = response.read()
-            return byte_array_content if encoding is None else byte_array_content.decode(encoding)
-        else:
-            exc = HTTPException('%s - %s' % (response.status, response.reason))
-            exc.status = response.status
-            exc.reason = response.reason
-            exc.headers = response.headers
-            exc.url = url
-            raise exc
-    finally:
-        conn.close()
+# from http.client import HTTPConnection, HTTPException
+# from urllib.parse import urlparse
+#
+#
+# def native_get(url, headers={}, encoding='utf-8'):
+#     url_parts = urlparse(url)
+#     conn = HTTPConnection(url_parts.hostname, port=url_parts.port if url_parts.port is not None else 80)
+#     try:
+#         conn.request('GET', url, headers=headers)
+#         response = conn.getresponse()
+#         if response.status == 200:
+#             byte_array_content = response.read()
+#             return byte_array_content if encoding is None else byte_array_content.decode(encoding)
+#         elif response.status == 301:
+#             byte_array_content = response.read()
+#             return byte_array_content if encoding is None else byte_array_content.decode(encoding)
+#         else:
+#             exc = HTTPException('%s - %s' % (response.status, response.reason))
+#             exc.status = response.status
+#             exc.reason = response.reason
+#             exc.headers = response.headers
+#             exc.url = url
+#             raise exc
+#     finally:
+#         conn.close()
 
 
 def requests_get(url, headers={}, encoding='utf-8', decode=True):
